#ifndef WR_IOCTL_H
#define WR_IOCTL_H 

#include <asm/types.h>


#pragma pack(push,1)

typedef struct
{
    __u8                    Request;
    __u16                   Value;
    __u16                   Index;
    void                    *Buffer;
    __u16                   Size;
    int                     Timeout;
} USB_CONTROL_MSG;

typedef struct
{
    __u8                    EndPoint;
    __u8                    *Buffer;
    __u32                   BufferSize;
    __u32                   Transferred;
    __u32                   Timeout;
} USB_BULK_MESSAGE;

typedef struct
{
    __u8                    EndPoint;
    void                   *Buffer;
    __u32                   BufferSize;
    void                   *CompletionRoutine;
    void                   *Data;
} USB_ASYNC_MESSAGE;

typedef struct
{
    void                   *CompletionRoutine;
    void                   *Data;
    void                   *Buffer;
    __u32                   BufferSize;
    __u32                   Transferred;
    __s32                   Status;
} USB_COMPLETE_ASYNC_MESSAGE;

typedef struct
{
    __u16       ByteCount;
    __u8        *Addresses;
    __u8        *Values;
} PIC_REG;


typedef struct
{
    __u8  Number;
    __u8  Address;
    __u16 MaxPacketSize;
} ENDPOINT_INFO;

typedef struct
{
    __u8            Count;
    ENDPOINT_INFO   EndPoint[16];
} ENDPOINTS;

typedef struct
{
    __u32 Address;
    __u32 Count;
    __u16 *Buffer;
} READ_WRITE_INFO;


#pragma pack(pop)

#define WRG3_MAGIC 0x8C

#define WRG3_IOCTL_GET_INTERFACE                        _IOR(WRG3_MAGIC,0x01,__u8)
#define WRG3_IOCTL_IS_CONNECTED                         _IOR(WRG3_MAGIC,0x02,__u8)

#define WRG3_IOCTL_PCI_READ_PIC_BYTES                   _IOWR(WRG3_MAGIC,0x06,PIC_REG)
#define WRG3_IOCTL_PCI_WRITE_PIC_BYTES                  _IOW(WRG3_MAGIC,0x07,PIC_REG)
#define WRG3_IOCTL_PCI_READ_PIC_BYTE                    _IOWR(WRG3_MAGIC,0x08,__u16)
#define WRG3_IOCTL_PCI_WRITE_PIC_BYTE                   _IOW(WRG3_MAGIC,0x09,__u16)
#define WRG3_IOCTL_PCI_WRITE                            _IOW(WRG3_MAGIC,0x0A,READ_WRITE_INFO)
#define WRG3_IOCTL_PCI_READ                             _IOWR(WRG3_MAGIC,0x0B,READ_WRITE_INFO)
#define WRG3_IOCTL_PCI_RESET                            _IO(WRG3_MAGIC,0x0C)
#define WRG3_IOCTL_PCI_WAIT_FOR_INTERRUPT               _IOR(WRG3_MAGIC,0x0D,__u32)
#define WRG3_IOCTL_PCI_START_INTERRUPT                  _IO(WRG3_MAGIC,0x0E)
#define WRG3_IOCTL_PCI_STOP_INTERRUPT                   _IO(WRG3_MAGIC,0x0F)


#define WRG3_IOCTL_USB_CONTROL_MESSAGE_SEND             _IOW(WRG3_MAGIC,0x20,USB_CONTROL_MSG)
#define WRG3_IOCTL_USB_CONTROL_MESSAGE_RECEIVE          _IOWR(WRG3_MAGIC,0x21,USB_CONTROL_MSG)
#define WRG3_IOCTL_USB_CONTROL_MESSAGE                  _IOW(WRG3_MAGIC,0x22,USB_CONTROL_MSG)
#define WRG3_IOCTL_USB_BULK_MESSAGE_SEND                _IOWR(WRG3_MAGIC,0x23,USB_BULK_MESSAGE)
#define WRG3_IOCTL_USB_BULK_MESSAGE_SEND_ASYNC          _IOW(WRG3_MAGIC,0x24,USB_ASYNC_MESSAGE)
#define WRG3_IOCTL_USB_BULK_MESSAGE_RECEIVE             _IOWR(WRG3_MAGIC,0x25,USB_BULK_MESSAGE)
#define WRG3_IOCTL_USB_BULK_MESSAGE_RECEIVE_ASYNC       _IOW(WRG3_MAGIC,0x26,USB_ASYNC_MESSAGE)
#define WRG3_IOCTL_USB_GET_COMPLETE_ASYNC_MESSAGE       _IOR(WRG3_MAGIC,0x27,USB_COMPLETE_ASYNC_MESSAGE)
#define WRG3_IOCTL_USB_START_ASYNC_MESSAGES             _IO(WRG3_MAGIC,0x28)
#define WRG3_IOCTL_USB_STOP_ASYNC_MESSAGES              _IO(WRG3_MAGIC,0x29)
#define WRG3_IOCTL_USB_CONFIGURE                        _IOR(WRG3_MAGIC,0x2A,__u8)
#define WRG3_IOCTL_USB_GET_ENDPOINTINFO                 _IOR(WRG3_MAGIC,0x2B,ENDPOINTS)
#define WRG3_IOCTL_USB_ISOC_MESSAGE_RECEIVE_ASYNC       _IOW(WRG3_MAGIC,0x2C,USB_ASYNC_MESSAGE)




#endif
